@@ -3,10 +3,10 @@ package DateTime::TimeZone::Alias;
 use strict;
 
 use Carp qw( croak );
-use DateTime::TimeZoneCatalog;
+use DateTime::TimeZone::Catalog;
 
 use vars qw( $VERSION );
-$VERSION = 0.0501;
+$VERSION = 0.06;
 
 sub import {
     my $class = shift;
@@ -25,23 +25,23 @@ sub set {
 
     foreach my $key ( keys %p ) {
     	if ( $class->is_alias( $p{ $key } ) ) {
-    		$DateTime::TimeZone::LINKS{ $key } =
-    			$DateTime::TimeZone::LINKS{ $p{ $key } }; 
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } =
+    			$DateTime::TimeZone::Catalog::LINKS{ $p{ $key } }; 
     	} elsif ( $class->is_timezone( $p{ $key } ) ) {
-    		$DateTime::TimeZone::LINKS{ $key } = $p{ $key };
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } = $p{ $key };
     	} elsif ( $p{ $key } eq 'floating' ) {
-    		$DateTime::TimeZone::LINKS{ $key } = 'floating';
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } = 'floating';
     	} elsif ( $p{ $key } eq 'local' ) {
-    		$DateTime::TimeZone::LINKS{ $key } = 'local';
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } = 'local';
     	} elsif ( $p{ $key } eq 'UTC' || $p{ $key } eq 'Z' ) {
-    		$DateTime::TimeZone::LINKS{ $key } = 'UTC';
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } = 'UTC';
     	} elsif ( $p{ $key } =~ /^ ([\+\-])? (\d\d?) :? (\d\d) (?::?(\d\d))? $/x ) {
         		my $sign	= $1 || '+';
     		my $hours	= $2;
     		my $minutes	= $3;
     		my $seconds	= sprintf( "%02d", $4 || 0 );
 
-    		$DateTime::TimeZone::LINKS{ $key } = "$sign$hours:$minutes:$seconds";
+    		$DateTime::TimeZone::Catalog::LINKS{ $key } = "$sign$hours:$minutes:$seconds";
     	} else {
     		croak "Aliases must point to a valid timezone or offset";
     	}
@@ -74,7 +74,7 @@ sub remove {
     		croak "Attempt to delete a nonexistant alias";
     	}
 
-    	delete $DateTime::TimeZone::LINKS{ $key };
+    	delete $DateTime::TimeZone::Catalog::LINKS{ $key };
     }
 }
 
@@ -82,7 +82,7 @@ sub value {
     my( $class, $key ) = @_;
 
     if ( $class->is_alias( $key ) ) {
-    	return $DateTime::TimeZone::LINKS{ $key };
+    	return $DateTime::TimeZone::Catalog::LINKS{ $key };
     } else {
     	return undef;
     }
@@ -104,7 +104,7 @@ sub is_defined {
 sub is_alias {
     my( $class, $alias_candidate ) = @_;
 
-    if ( exists $DateTime::TimeZone::LINKS{ $alias_candidate } ) {
+    if ( exists $DateTime::TimeZone::Catalog::LINKS{ $alias_candidate } ) {
     	return 1;
     } else {
     	return undef;
@@ -114,7 +114,7 @@ sub is_alias {
 sub is_timezone {
     my( $class, $tz_candidate ) = @_;
 
-    if ( grep( /^\Q${tz_candidate}\E$/, @DateTime::TimeZone::ALL ) ) {
+    if ( grep( /^\Q${tz_candidate}\E$/, @DateTime::TimeZone::Catalog::ALL ) ) {
     	return 1;
     } else {
     	return undef;
@@ -127,9 +127,9 @@ sub aliases {
     return unless defined wantarray;
 
     if ( wantarray ) {
-    	return %DateTime::TimeZone::LINKS;
+    	return %DateTime::TimeZone::Catalog::LINKS;
     } else {
-    	my %dttz_links_copy = %DateTime::TimeZone::LINKS;
+    	my %dttz_links_copy = %DateTime::TimeZone::Catalog::LINKS;
     	return \%dttz_links_copy;
     }
 }
@@ -140,9 +140,9 @@ sub timezones {
     return unless defined wantarray;
 
     if ( wantarray ) {
-    	return @DateTime::TimeZone::ALL;
+    	return @DateTime::TimeZone::Catalog::ALL;
     } else {
-    	my @dttz_all_copy = @DateTime::TimeZone::ALL;
+    	my @dttz_all_copy = @DateTime::TimeZone::Catalog::ALL;
     	return \@dttz_all_copy;
     }
 }
